/* Company.do (STATA)
	Aggregate reinsurance data by company. 
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using Company, replace;

/* Set parameters */

scalar lossRatio = .25;	/* Loss ratio */

/* Operating companies */

u data\Unauthorized if shadow, clear;

collapse (sum) Trust_Agreements, by(Years AMB_Number);

save data\Company, replace;

u data\Reinsurance, clear;

gen netReserveS = netReserve if shadow;
gen netReserveSL = netReserve if shadow & category=="Life";
gen netReserveSA = netReserve if shadow & category=="Annuity";

gen byte shadowL = shadow & category=="Life";
gen byte shadowA = shadow & category=="Annuity";

collapse (sum) netReserve netReserveS netReserveSL netReserveSA (max) shadow shadowL shadowA,
	by(Years AMB_Number AMB_Company_Name);

merge 1:1 Years AMB_Number using data\Company,
	nogen keep(master match);

/* Merge Liabilities, Surplus & Other Funds */

merge 1:1 Years AMB_Number
	using "data\3 Liabilities, Surplus & Other Funds",
	keepusing(liab Lliab)
	nogen keep(using match);

/* Merge Exhibit 5 - Aggregate Reserve for Life Contracts */

merge 1:1 Years AMB_Number
	using "data\12 Exhibit 5 - Aggregate Reserve for Life Contracts",
	keepusing(Total_life_ins_rsv_gross Total_annuities_rsv_gross rsv_gross
	LNrsv_gross LNlife_ins LNannuities Drsv_gross Dlife_ins Dannuities)
	nogen keep(using match);

/* Merge Exhibit of Life Insurance (Continued) */

merge 1:1 Years AMB_Number
	using "data\26 Exhibit of Life Insurance (Continued)",
	keepusing(SIn_frc_end_yr_amt SIn_frc_end_yr_amt1)
	nogen keep(using match);

/* Merge Schedule S Part 6 */

merge 1:1 Years AMB_Number
	using "data\47 Schedule S Part 6",
	keepusing(As_reported_total_assets As_reported_total_liabilities As_rep_capital___surplus
	LNassets LNliabilities LNcapital leverage)
	nogen keep(using match);

/* Merge All General Information */

merge 1:1 Years AMB_Number
	using "data\All General Information",
	keepusing(AMB_Financial_Group_Number AMB_Financial_Group_Name Aggregation_Code State_of_Domicile
	Best_s_FSR___Current Financial_Size_Category_Code Best_s_Capital_Adequacy_Ratio stock stock1)
	nogen keep(using match);

/* Merge Liquidity Analysis */

merge 1:1 Years AMB_Number
	using "data\Liquidity Analysis",
	keepusing(Current_liquidity)
	nogen keep(using match);

/* Merge Profitability Analysis */

merge 1:1 Years AMB_Number
	using "data\Profitability Analysis",
	keepusing(Return_on_equity)
	nogen keep(using match);

/* Merge life insurance prices */

merge 1:1 Years AMB_Number using data\Premiums,
	nogen keep(master match);

/* Merge savings from the Flow of Funds */

merge m:1 Years using "data\F100",
	nogen keep(master match);

/* Merge US Treasury yields */

merge m:1 Years using "data\US Treasury Yields",
	keepusing(Yield* Capacity)
	nogen keep(master match);

/* Merge AMB default rates */

merge m:1 Best_s_FSR using "data\AMB Default Rates",
	keepusing(Guideline Cumulative* Marginal*)
	nogen keep(master match);

/* Fix variables */

recode netReserve netReserveS netReserveSL netReserveSA shadow shadowL shadowA Trust_Agreements (.=0);

egen Amarkup = mean(markup), by(Years AMB_Financial_Group_Number);
replace markup = Amarkup if markup==.;
drop Amarkup;

/* Create variables */

gen stock_SIn_frc1 = stock1*SIn_frc_end_yr_amt1;

gen rsv_grossS = 100*min(netReserveS/rsv_gross,1) if rsv_gross>0;
gen rsv_grossSL = 100*min(netReserveSL/Total_life_ins_rsv_gross,1) if Total_life_ins_rsv_gross>0;
gen rsv_grossSA = 100*min(netReserveSA/Total_annuities_rsv_gross,1) if Total_annuities_rsv_gross>0;

gen AMB_Reinsurer_Company_Number__Re = AMB_Number;

gen liabA = liab;
gen LliabA = Lliab;

/* Adjustment for shadow insurance */

gen LNliabilitiesS = ln(As_reported_total_liabilities+netReserveS);

gen leverageS = 100*(As_reported_total_liabilities+netReserveS)/(As_reported_total_assets+netReserveS);

gen Best_s_CapitalS = Best_s_Capital_Adequacy_Ratio;
replace Best_s_CapitalS = Best_s_Capital_Adequacy_Ratio/(1+netReserveS/liab) if liab>0;

gen GuidelineS = Guideline;
replace GuidelineS = Guideline/(1+netReserveS/liab) if liab>0;

gen ratingS = "A++" if GuidelineS>=167.5 & GuidelineS<.;
replace ratingS = "A+" if GuidelineS>=152.5 & GuidelineS<167.5;
replace ratingS = "A" if GuidelineS>=137.5 & GuidelineS<152.5;
replace ratingS = "A-" if GuidelineS>=125 & GuidelineS<137.5;
replace ratingS = "B++" if GuidelineS>=115 & GuidelineS<125;
replace ratingS = "B+" if GuidelineS>=105 & GuidelineS<115;
replace ratingS = "B" if GuidelineS>=95 & GuidelineS<105;
replace ratingS = "B-" if GuidelineS>=85 & GuidelineS<95;
replace ratingS = "C++" if GuidelineS>=75 & GuidelineS<85;
replace ratingS = "C+" if GuidelineS>=65 & GuidelineS<75;
replace ratingS = "C" if GuidelineS>=55 & GuidelineS<65;
replace ratingS = "C-" if GuidelineS>=25 & GuidelineS<55;
replace ratingS = "D" if GuidelineS>=0 & GuidelineS<25;

/* Compute expected loss */

gen loss = liab*lossRatio*
	(Marginal1/exp(Yield1/100)+Marginal2/exp(2*Yield2/100)+Marginal3/exp(3*Yield3/100)
	+Marginal4/exp(4*Yield4/100)+Marginal5/exp(5*Yield5/100)+Marginal6/exp(6*Yield6/100)
	+Marginal7/exp(7*Yield7/100)+Marginal8/exp(8*Yield8/100)+Marginal9/exp(9*Yield9/100)
	+Marginal10/exp(10*Yield10/100)+Marginal11/exp(11*Yield11/100)+Marginal12/exp(12*Yield12/100)
	+Marginal13/exp(13*Yield13/100)+Marginal14/exp(14*Yield14/100)+Marginal15/exp(15*Yield15/100));

gen Default = 100*Cumulative10;

drop Cumulative* Marginal*;
	
merge m:1 ratingS using "data\AMB Default Rates",
	keepusing(Cumulative* Marginal*)
	nogen keep(master match);

gen lossS = (liab+netReserveS)*lossRatio*
	(Marginal1/exp(Yield1/100)+Marginal2/exp(2*Yield2/100)+Marginal3/exp(3*Yield3/100)
	+Marginal4/exp(4*Yield4/100)+Marginal5/exp(5*Yield5/100)+Marginal6/exp(6*Yield6/100)
	+Marginal7/exp(7*Yield7/100)+Marginal8/exp(8*Yield8/100)+Marginal9/exp(9*Yield9/100)
	+Marginal10/exp(10*Yield10/100)+Marginal11/exp(11*Yield11/100)+Marginal12/exp(12*Yield12/100)
	+Marginal13/exp(13*Yield13/100)+Marginal14/exp(14*Yield14/100)+Marginal15/exp(15*Yield15/100));

gen DefaultS = 100*Cumulative10;

drop Yield* Cumulative* Marginal*;

/* Screening criteria */

keep if AMB_Financial_Group_Number<.;
keep if regexm(Aggregation,"A|U");
drop if State=="";

drop if LNassets==.;

/* Save data */

sort Years AMB_Number;

save data\Company, replace;


/* Affiliated reinsurers */

u data\Reinsurance, clear;

replace netReserve = -netReserve;

egen temp1 = min(AMB_Financial_Group_Number) if affiliated, by(Years amb_reinsurer_company_name Domicile);
egen temp2 = max(AMB_Financial_Group_Number) if affiliated, by(Years amb_reinsurer_company_name Domicile);

replace AMB_Financial_Group_Number = . if temp1!=temp2;

collapse (sum) netReserve (max) AMB_Financial_Group_Number affiliated captive (min) authorized,
	by(Years AMB_Reinsurer_Company_Number amb_reinsurer_company_name Domicile Best_s_Rating___Current__Rein);

/* Merge operating companies */

merge m:1 Years AMB_Reinsurer_Company_Number using data\Company,
	keepusing(liabA LliabA)
	keep(master match);

/* Create variables */

gen byte operating = _merge==3;

replace liabA = -netReserve if _merge==1 & captive;

sort amb_reinsurer_company_name Domicile Years;
by amb_reinsurer_company_name Domicile: replace LliabA = liabA[_n-1]
	if _merge==1 & captive & Years==Years[_n-1]+1;
by amb_reinsurer_company_name Domicile: replace LliabA = 0
	if _merge==1 & captive & Years>=2003 & _n==1;

drop _merge;

/* Screening criteria */

keep if affiliated;

drop affiliated;

/* Save data */

sort Years AMB_Reinsurer_Company_Number amb_reinsurer_company_name Domicile;

compress;

save data\Reinsurer, replace;

log close;
