/* Estimation1.do (STATA)
	Estimate structural model of the life insurance market. 
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;
set seed 1;

cap log close;
log using Estimation1, replace;

u data\Company if Years>=2002 & regexm(Best_s_FSR,"^(A|B|C|D)") & Dlife_ins>0 & Dlife_ins<., clear;

/* Set parameters */

scalar Nsim = 100;	/* Number of simulations */

/* Create variables */

egen Tlife_ins = sum(Dlife_ins), by(Years);
gen Slife_ins = Dlife_ins/(Savings+Tlife_ins);

egen _LNlife_ins = std(LNlife_ins);
*egen _leverage = std(leverage);
*egen _Best_s_Capital = std(Best_s_Capital_Adequacy_Ratio);
egen _Current_liquidity = std(Current_liquidity);
egen _Return_on_equity = std(Return_on_equity);
*egen _Guideline = std(Guideline);
egen _stock_SIn_frc1 = std(stock_SIn_frc1);

egen M_leverage = mean(leverage);
egen S_leverage = sd(leverage);
gen _leverage = (leverage-M_leverage)/S_leverage;
gen _leverageS = (leverageS-M_leverage)/S_leverage;

egen M_Best_s_Capital = mean(Best_s_Capital_Adequacy_Ratio);
egen S_Best_s_Capital = sd(Best_s_Capital_Adequacy_Ratio);
gen _Best_s_Capital = (Best_s_Capital_Adequacy_Ratio-M_Best_s_Capital)/S_Best_s_Capital;
gen _Best_s_CapitalS = (Best_s_CapitalS-M_Best_s_Capital)/S_Best_s_Capital;

egen M_Guideline = mean(Guideline);
egen S_Guideline = sd(Guideline);
gen _Guideline = (Guideline-M_Guideline)/S_Guideline;
gen _GuidelineS = (GuidelineS-M_Guideline)/S_Guideline;

drop M_* S_*;

gen _LNlife_ins2 = _LNlife_ins^2;
gen _leverage2 = _leverage^2;
gen _Best_s_Capital2 = _Best_s_Capital^2;
gen _Current_liquidity2 = _Current_liquidity^2;
gen _Return_on_equity2 = _Return_on_equity^2;
gen _Guideline2 = _Guideline^2;

char Years[omit] 2012;
char AMB_Financial_Group_Number[omit] 70192;

xi i.Years;

/* Simulate random coefficients */

*gen Imarkup = rnormal(0,1) if _n<=Nsim;
gen I_LNlife_ins = rnormal(0,1) if _n<=Nsim;
gen I_Guideline = rnormal(0,1) if _n<=Nsim;
*gen I_Best_s_Capital = rnormal(0,1) if _n<=Nsim;
gen I_leverage = rnormal(0,1) if _n<=Nsim;

/* Estimate demand - initial guess */

blp Slife_ins
	_LNlife_ins _Guideline _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	if markup<.,
	endog(markup = shadow _LNlife_ins2 _Guideline2 _Best_s_Capital2 _leverage2 _Current_liquidity2 _Return_on_equity2)
	stochastic(_LNlife_ins,_Guideline,_leverage)
	markets(Years)
	draws(`=Nsim') initsd(.19,.27,.29) robust;

mat binit = e(b);

/* Compute mean utility, demand elasticity, and marginal cost */

qui gen utility = _b[cons]
	+_b[_LNlife_ins]*_LNlife_ins+_b[_Guideline]*_Guideline+_b[_Best_s_Capital]*_Best_s_Capital+_b[_leverage]*_leverage
	+_b[_Current_liquidity]*_Current_liquidity+_b[_Return_on_equity]*_Return_on_equity+_b[stock]*stock
	+_b[markup]*markup;

utility _b[markup] _b[_LNlife_ins:SD] _b[_Guideline:SD] _b[_leverage:SD];

/* Estimate supply - initial guess */

reg LNcost shadow
	_LNlife_ins _Guideline _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_IYears_*,
	vce(robust);

mat binit = (binit,e(b));

drop utility elast cost LNcost;

/* GMM estimation of demand and supply */

gmm gmm_blp if markup<., nequations(2)
	parameters(D:_cons
	D:_LNlife_ins D:_Guideline D:_Best_s_Capital D:_leverage D:_Current_liquidity D:_Return_on_equity D:stock
	D:markup
	SD:_LNlife_ins SD:_Guideline SD:_leverage
	MC:shadow
	MC:_LNlife_ins MC:_Guideline MC:_Best_s_Capital MC:_leverage MC:_Current_liquidity MC:_Return_on_equity MC:stock
	MC:_IYears_2002 MC:_IYears_2003 MC:_IYears_2004 MC:_IYears_2005 MC:_IYears_2006 MC:_IYears_2007 MC:_IYears_2008 MC:_IYears_2009 MC:_IYears_2010 MC:_IYears_2011
	MC:_cons)
	instruments(1: shadow
	_LNlife_ins _Guideline _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_LNlife_ins2 _Guideline2 _Best_s_Capital2 _leverage2 _Current_liquidity2 _Return_on_equity2)
	instruments(2: shadow
	_LNlife_ins _Guideline _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_IYears_*)
	twostep wmat(robust) winit(unadjusted, independent)
	from(binit);

estat overid;

estimates save data\Estimation1a, replace;

mat binit = e(b);

/* Compute mean utility, demand elasticity, and marginal cost */

qui gen utility = _b[D:_cons]
	+_b[D:_LNlife_ins]*_LNlife_ins+_b[D:_Guideline]*_Guideline+_b[D:_Best_s_Capital]*_Best_s_Capital+_b[D:_leverage]*_leverage
	+_b[D:_Current_liquidity]*_Current_liquidity+_b[D:_Return_on_equity]*_Return_on_equity+_b[D:stock]*stock
	+_b[D:markup]*markup;

utility _b[D:markup] _b[SD:_LNlife_ins] _b[SD:_Guideline] _b[SD:_leverage];

/* Save data */

save data\Estimation1, replace;


/* GMM estimation of demand and supply with term life instrument */

gmm gmm_blp if markup<., nequations(2)
	parameters(D:_cons
	D:_LNlife_ins D:_Guideline D:_Best_s_Capital D:_leverage D:_Current_liquidity D:_Return_on_equity D:stock
	D:markup
	SD:_LNlife_ins SD:_Guideline SD:_leverage
	MC:shadow
	MC:_LNlife_ins MC:_Guideline MC:_Best_s_Capital MC:_leverage MC:_Current_liquidity MC:_Return_on_equity MC:stock
	MC:_IYears_2002 MC:_IYears_2003 MC:_IYears_2004 MC:_IYears_2005 MC:_IYears_2006 MC:_IYears_2007 MC:_IYears_2008 MC:_IYears_2009 MC:_IYears_2010 MC:_IYears_2011
	MC:_cons)
	instruments(1: shadow
	_LNlife_ins _Guideline _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_LNlife_ins2 _Guideline2 _Best_s_Capital2 _leverage2 _Current_liquidity2 _Return_on_equity2)
	instruments(2: _stock_SIn_frc1
	_LNlife_ins _Guideline _Best_s_Capital _leverage _Current_liquidity _Return_on_equity stock
	_IYears_*)
	twostep wmat(robust) winit(unadjusted, independent)
	from(binit);

estat overid;

estimates save data\Estimation1b, replace;

log close;
