/* Estimation2.do (STATA)
	Estimate the life insurance market without shadow insurance. 
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;

cap log close;
log using Estimation2, replace;

u data\Estimation1, clear;

estimates use data\Estimation1a;

/* Set parameters */

scalar Nsim = 100;	/* Number of simulations */

/* Life insurance market without shadow insurance
	Case 1: Without adjustment to ratings
	Case 2: With adjustment to ratings */

forval i = 1/2 {;

/* Compute marginal cost without shadow insurance */

qui gen LNcostNew = LNcost-_b[MC:shadow]*shadow
	+(`i'==2)*(_b[MC:_Guideline]*(_GuidelineS-_Guideline)+_b[MC:_Best_s_Capital]*(_Best_s_CapitalS-_Best_s_Capital)+_b[MC:_leverage]*(_leverageS-_leverage));

qui gen costNew = exp(LNcostNew);

/* Compute equilibrium price */

qui gen markupNew = costNew/(1-1/elast);

forval j = 1/100 {;
	qui gen utilityNew = utility+_b[D:markup]*(markupNew-markup)
		+(`i'==2)*(_b[D:_Guideline]*(_GuidelineS-_Guideline)+_b[D:_Best_s_Capital]*(_Best_s_CapitalS-_Best_s_Capital)+_b[D:_leverage]*(_leverageS-_leverage));
	
	gen Slife_insNew = 0;
	gen elastNew = 0;
	
	forval n = 1/`=Nsim' {;
		qui gen share1 = exp(utilityNew
			+_b[SD:_LNlife_ins]*I_LNlife_ins[`n']*_LNlife_ins+_b[SD:_Guideline]*I_Guideline[`n']*_Guideline+_b[SD:_leverage]*I_leverage[`n']*_leverage
			+(`i'==2)*(_b[SD:_Guideline]*I_Guideline[`n']*(_GuidelineS-_Guideline)+_b[SD:_leverage]*I_leverage[`n']*(_leverageS-_leverage)));
		egen share2 = sum(share1), by(Years);
		qui gen share = share1/(1+share2);
		
		qui replace Slife_insNew = Slife_insNew+share/Nsim;
		qui replace elastNew = elastNew-_b[D:markup]*share*(1-share)/Nsim;
		
		drop share1 share2 share;
	};
	
	qui replace elastNew = markupNew/Slife_insNew*elastNew;
	qui replace elastNew = min(elastNew,elast) if elast<2;
	
	/* Check convergence */
	
	qui gen diff = costNew/(1-1/elastNew)-markupNew;
	
	qui sum diff;
	local Mdiff = max(abs(r(min)),abs(r(max)));
	*di `Mdiff';
	
	/* Update price */
	
	qui replace markupNew = markupNew+diff;
	
	/* Exit if converged */
	
	if `j'==100 | `Mdiff'<1e-5 {;
		continue, break;
	};
	
	drop utilityNew Slife_insNew elastNew diff;
};

/* Create variables */

qui gen Dlife_insNew = Slife_insNew*(Savings+Tlife_ins);

qui gen Ccost = 100*(costNew/cost-1);
qui gen Cmarkup = 100*(markupNew/markup-1);

qui gen Dquantity = Dlife_insNew-Dlife_ins;

/* Output table */

tabstat Ccost Cmarkup if Years==2012 & shadow,
	stat(mean) c(stat);

tabstat Dquantity Dlife_ins if Years==2012,
	by(shadow) stat(sum) c(stat);

tabstat elast elastNew if Years==2012,
	stat(mean);

drop *New diff Ccost Cmarkup Dquantity;
};

log close;
