/* Plots1.do (STATA)
	Plot aggregate trends in reinsurance.
	by Motohiro Yogo. */

#delimit ;
clear all;
set more off;
set scheme s1mono;

cap log close;
log using Plots1, replace;

/* Affiliated vs. unaffiliated reinsurance */

u data\Reinsurance if ceded, clear;

collapse (sum) netReserve, by(Years affiliated);

sort affiliated Years;
l affiliated Years netReserve, noobs clean;

label var netReserve "Reinsurance ceded (billion $)";

twoway (line netReserve Years if affiliated, lc(black) lp(solid))
	(line netReserve Years if !affiliated, lc(black) lp(dash)),
	ylabel(100(100)600, angle(0))
	legend(label(1 "Affiliated") label(2 "Unaffiliated")
	pos(11) ring(0) col(1));

graph export ..\figures\Reinsurance.eps, replace;

/* Life vs. annuity reinsurance */

u data\Reinsurance if ceded, clear;

collapse (sum) netReserve, by(Years affiliated category);

sort category affiliated Years;
l category affiliated Years netReserve, noobs clean;

label var netReserve "Reinsurance ceded (billion $)";

twoway (line netReserve Years if affiliated & category=="Life", lc(black) lp(solid))
	(line netReserve Years if !affiliated & category=="Life", lc(black) lp(dash)),
	ylabel(0(100)400, angle(0))
	legend(label(1 "Affiliated") label(2 "Unaffiliated")
	pos(11) ring(0) col(1))
	title("Life reinsurance")
	saving(Plot1, replace);
	
twoway (line netReserve Years if affiliated & category=="Annuity", lc(black) lp(solid))
	(line netReserve Years if !affiliated & category=="Annuity", lc(black) lp(dash)),
	ylabel(0(100)400, angle(0))
	legend(off)
	title("Annuity reinsurance")
	saving(Plot2, replace);

graph combine Plot1.gph Plot2.gph, 
    rows(2) cols(1) xcommon ycommon altshrink imargin(medium) xsize(6) ysize(9);

graph export ..\figures\Type.eps, replace;

rm Plot1.gph;
rm Plot2.gph;

/* Reinsurance pricing */

u data\Reinsurance if ceded & first & regexm(Type,"^(CO$|CO/)"), clear;

collapse (median) price, by(Years affiliated);

label var price "Premium (share of reserve credit)";

twoway (line price Years if affiliated, lc(black) lp(solid))
	(line price Years if !affiliated, lc(black) lp(dash)),
	ylabel(0(.5)2, angle(0))
	legend(label(1 "Affiliated") label(2 "Unaffiliated")
	pos(11) ring(0) col(1));

graph export ..\figures\Pricing.eps, replace;


/* Reinsurance by geography */

u data\Reinsurance if ceded, clear;

gen Order = 1 if !usDomicile;
replace Order = 3 if usDomicile;
replace Order = 2 if regexm(Domicile,"Bermuda|Barbados|Cayman Islands");
replace Order = 4 if regexm(Domicile,"South Carolina|Vermont"); 

collapse (sum) netReserve, by(Years affiliated Order);

gsort Years affiliated -Order;
by Years affiliated: gen CumSum = netReserve if _n==1;
by Years affiliated: replace CumSum = netReserve+CumSum[_n-1] if _n>1;

egen Sum = sum(netReserve), by(Years affiliated);

gen Share = CumSum/Sum;

gsort affiliated -Order Years;
l affiliated Order Years Share, noobs clean;

label var Share "Share of total reinsurance ceded";

twoway (area Share Years if affiliated & Order==1, col(ltblue))
	(area Share Years if affiliated & Order==2, col(midblue))
	(area Share Years if affiliated & Order==3, col(blue))
	(area Share Years if affiliated & Order==4, col(navy)),
	ylabel(0(.2)1, angle(0))
	legend(off)
	title("Affiliated reinsurance")	
	saving(Plot1, replace);

twoway (area Share Years if !affiliated & Order==1, col(ltblue))
	(area Share Years if !affiliated & Order==2, col(midblue))
	(area Share Years if !affiliated & Order==3, col(blue))
	(area Share Years if !affiliated & Order==4, col(navy)),
	ylabel(0(.2)1, angle(0))
	legend(label(1 "Other international") label(2 "Bermuda, Barbados" "& Cayman Islands")
	label(3 "Other U.S.") label(4 "South Carolina &" "Vermont")
	pos(3) ring(0) col(1))
	title("Unaffiliated reinsurance")	
	saving(Plot2, replace);

graph combine Plot1.gph Plot2.gph, 
    rows(2) cols(1) xcommon ycommon altshrink imargin(medium) xsize(6) ysize(9);

graph export ..\figures\Geography.eps, replace;	

rm Plot1.gph;
rm Plot2.gph;

/* Reinsurance by rating */

u data\Reinsurance if ceded, clear;

gen Order = 3;
replace Order = 1 if regexm(Best_s_Rating___Current__Rein,"^(A\+\+|A\+)$");
replace Order = 2 if regexm(Best_s_Rating___Current__Rein,"^(A|A-|B\+\+|B\+|B|B-|C\+\+|C\+|C|C-|D|E|F)$");

collapse (sum) netReserve, by(Years affiliated Order);

gsort Years affiliated -Order;
by Years affiliated: gen CumSum = netReserve if _n==1;
by Years affiliated: replace CumSum = netReserve+CumSum[_n-1] if _n>1;

egen Sum = sum(netReserve), by(Years affiliated);

gen Share = CumSum/Sum;

gsort affiliated -Order Years;
l affiliated Order Years Share, noobs clean;

label var Share "Share of total reinsurance ceded";

twoway (area Share Years if affiliated & Order==1, col(ltblue))
	(area Share Years if affiliated & Order==2, col(midblue))
	(area Share Years if affiliated & Order==3, col(blue)),
	ylabel(0(.2)1, angle(0))
	legend(label(1 "A++ or A+") label(2 "A or lower") label(3 "Unrated")
	pos(11) ring(0) col(1))
	title("Affiliated reinsurance")	
	saving(Plot1, replace);

twoway (area Share Years if !affiliated & Order==1, col(ltblue))
	(area Share Years if !affiliated & Order==2, col(midblue))
	(area Share Years if !affiliated & Order==3, col(blue)),
	ylabel(0(.2)1, angle(0))
	legend(off)
	title("Unaffiliated reinsurance")
	saving(Plot2, replace);

graph combine Plot1.gph Plot2.gph, 
    rows(2) cols(1) xcommon ycommon altshrink imargin(medium) xsize(6) ysize(9);

graph export ..\figures\Rating.eps, replace;	

rm Plot1.gph;
rm Plot2.gph;

/* Reinsurance to unauthorized reinsurers */

u data\Reinsurance if ceded, clear;

collapse (sum) netReserve, by(Years affiliated authorized);

sort Years affiliated authorized;
by Years affiliated: gen CumSum = netReserve if _n==1;
by Years affiliated: replace CumSum = netReserve+CumSum[_n-1] if _n>1;

egen Sum = sum(netReserve), by(Years affiliated);

gen Share = CumSum/Sum;

sort affiliated authorized Years;
l affiliated authorized Years Share, noobs clean;

label var Share "Share of total reinsurance ceded";

twoway (area Share Years if affiliated & authorized, col(ltblue))
	(area Share Years if affiliated & !authorized, col(blue)),
	ylabel(0(.2)1, angle(0))
	legend(label(1 "Authorized") label(2 "Unauthorized")
	pos(11) ring(0) col(1))
	title("Affiliated reinsurance")	
	saving(Plot1, replace);

twoway (area Share Years if !affiliated & authorized, col(ltblue))
	(area Share Years if !affiliated & !authorized, col(blue)),
	ylabel(0(.2)1, angle(0))
	legend(off)
	title("Unaffiliated reinsurance")
	saving(Plot2, replace);

graph combine Plot1.gph Plot2.gph, 
    rows(2) cols(1) xcommon ycommon altshrink imargin(medium) xsize(6) ysize(9);

graph export ..\figures\Unauthorized.eps, replace;	

rm Plot1.gph;
rm Plot2.gph;

/* Funding structure of unauthorized reinsurance */

u data\Unauthorized if Reserve_Credit_Taken>=0, clear;

collapse (sum) Letters_of_Credit Trust_Agreements Funds_Deposited, by(Years affiliated);

sort Years affiliated;
by Years affiliated: gen Sum = Letters_of_Credit+Trust_Agreements+Funds_Deposited;

gen Share3 = Letters_of_Credit/Sum;
gen Share2 = Share3+Trust_Agreements/Sum;
gen Share1 = Share2+Funds_Deposited/Sum;

sort affiliated Years;
l affiliated Years Share*, noobs clean;

twoway area Share1 Share2 Share3 Years if affiliated,
	col(ltblue midblue blue)
	ylabel(0(.2)1, angle(0))
	ytitle("Share of total reserve credit")
	legend(label(1 "Funds withheld") label(2 "Trust agreement") label(3 "Letter of credit")
	pos(11) ring(0) col(1))
	title("Affiliated reinsurance")	
	saving(Plot1, replace);

twoway area Share1 Share2 Share3 Years if !affiliated,
	col(ltblue midblue blue)
	ylabel(0(.2)1, angle(0))
	ytitle("Share of total reserve credit")
	legend(off)
	title("Unaffiliated reinsurance")	
	saving(Plot2, replace);

graph combine Plot1.gph Plot2.gph, 
    rows(2) cols(1) xcommon ycommon altshrink imargin(medium) xsize(6) ysize(9);

graph export ..\figures\Funding.eps, replace;

rm Plot1.gph;
rm Plot2.gph;

/* Reinsurance by contract */

u data\Reinsurance if ceded, clear;

gen Order = 1;
replace Order = 2 if regexm(Type,"^(MCO|AMCO)");
replace Order = 3 if regexm(Type,"^(CO$|CO/|COF|ACO$|ACO/|ACOF)");

collapse (sum) netReserve, by(Years category Order);

gsort Years category -Order;
by Years category: gen CumSum = netReserve if _n==1;
by Years category: replace CumSum = netReserve+CumSum[_n-1] if _n>1;

egen Sum = sum(netReserve), by(Years category);

gen Share = CumSum/Sum;

label var Share "Share of total reinsurance ceded";

twoway (area Share Years if category=="Life" & Order==1, col(ltblue))
	(area Share Years if category=="Life" & Order==2, col(midblue))
	(area Share Years if category=="Life" & Order==3, col(blue)),
	ylabel(0(.2)1, angle(0))
	legend(label(1 "Combination coinsurance & other") label(2 "Modified coinsurance") label(3 "Coinsurance")
	pos(7) ring(0) col(1))
	title("Life reinsurance")	
	saving(Plot1, replace);

twoway (area Share Years if category=="Annuity" & Order==1, col(ltblue))
	(area Share Years if category=="Annuity" & Order==2, col(midblue))
	(area Share Years if category=="Annuity" & Order==3, col(blue)),
	ylabel(0(.2)1, angle(0))
	legend(off)
	title("Annuity reinsurance")
	saving(Plot2, replace);

graph combine Plot1.gph Plot2.gph, 
    rows(2) cols(1) xcommon ycommon altshrink imargin(medium) xsize(6) ysize(9);

graph export ..\figures\Contract.eps, replace;	

rm Plot1.gph;
rm Plot2.gph;

log close;
